
//////////////////////////
#version 150
#pragma optimize(on)
#pragma debug(off)
#extension all : disable
//////////////////////////


// -- Uniform --
uniform sampler2D Sampler_Diffuse;
uniform sampler2DShadow Sampler_ShadowMap;

// -- Lighting --
uniform vec3 LightPosition;
uniform vec3 LightDirection;
uniform vec4 LightAmbient;
uniform vec4 LightDiffuse;
uniform vec4 LightSpecular;
uniform vec3 CameraPosition;

// -- Material --
uniform vec4 MaterialSpecular;
uniform float MaterialShininess;


// -- Input fragment --
in vec2 fTex0;
in vec3 fNormal;
in vec4 fPosWorld;
in vec4 fProjCoordSM;


// -- Fragment output --
out vec4 outColor;


// -- Calculate Parallel light --
vec4 ParallelLight(vec4 diffuseColor)
{
	vec4 color = LightAmbient * diffuseColor;
	
	float kd = dot(-LightDirection, fNormal);
	if (kd > 0) {
	
		vec3 vecView = normalize(CameraPosition - fPosWorld.xyz);
		vec3 vecRefl = reflect(LightDirection, fNormal);
		float ks = pow(max(dot(vecRefl, vecView), 0.0f), MaterialShininess);
		
		color += LightDiffuse * diffuseColor * kd;
		color += LightSpecular * MaterialSpecular * ks;
	}
	
	return color;
}


// -- Main --
void main(void)
{
	outColor = ParallelLight(texture(Sampler_Diffuse, fTex0.xy));

	// shadow map look up

	vec3 smTex = fProjCoordSM.xyz / fProjCoordSM.w;
	//smTex = 0.5 + smTex * 0.5;
	float smDepth = texture(Sampler_ShadowMap, smTex).x;
	
	float smOffset = 0.0001;
	float dotNL = dot(vec3(0, 1, 0), fNormal);
	if (dotNL < 0.2) {
		smOffset = 0.0001;
	}
	if (smDepth + smOffset < smTex.z) {
		outColor *= 0.1;
	}
	
	//outColor.rgb = outColor.rgb * 0.001 + vec3(smOffset, smOffset, smOffset) * 0.999;
	
	/**
	vec4 smTex = fProjCoordSM;
	float smDepth = textureProj(Sampler_ShadowMap, smTex);
	if (smDepth < 0.8) {
		outColor.rgb *= smDepth;
	}**/
}
