
//////////////////////////
#version 150
#pragma optimize(on)
#pragma debug(off)
#extension all : disable
//////////////////////////


// -- Uniform --
uniform sampler2D Sampler_Diffuse;

// -- Lighting --
uniform vec3 LightPosition;
uniform vec3 LightDirection;
uniform vec4 LightAmbient;
uniform vec4 LightDiffuse;
uniform vec4 LightSpecular;
uniform vec3 CameraPosition;

// -- Material --
uniform vec4 MaterialSpecular;
uniform float MaterialShininess;


// -- Input fragment --
in vec2 fTex0;
in vec3 fNormal;
in vec4 fPosWorld;

// -- Fragment output --
out vec4 outColor;

// -- Calculate Parallel light --
vec4 ParallelLight(vec4 diffuseColor)
{
	vec4 color = LightAmbient * diffuseColor;
	
	float kd = dot(-LightDirection, fNormal);
	if (kd > 0) {
	
		vec3 vecView = normalize(CameraPosition - fPosWorld.xyz);
		vec3 vecRefl = reflect(LightDirection, fNormal);
		float ks = pow(max(dot(vecRefl, vecView), 0.0f), MaterialShininess);
		
		color += LightDiffuse * diffuseColor * kd;
		color += LightSpecular * MaterialSpecular * ks;
	}
	return color;
}


// -- Main --
void main(void)
{
	outColor = texture(Sampler_Diffuse, fTex0.xy);
}