
//////////////////////////
#version 150
#pragma optimize(on)
#pragma debug(off)
#extension all : disable
//////////////////////////


// -- Uniform --
uniform sampler2D Sampler_Reflection;
uniform sampler2D Sampler_Refraction;
uniform sampler2D Sampler_WaterRipples;


// -- Input fragment --
in vec4 fProjCoord;
in vec2 fWaveTex0;
in vec2 fWaveTex1;
in vec2 fWaveTex2;
in vec2 fWaveTex3;


// -- Fragment output --
out vec4 outColor;


// -- Main --
void main(void)
{
	// Get rippled water texture
	vec3 rippleTex0 = texture(Sampler_WaterRipples, fWaveTex0).xyz;
    vec3 rippleTex1 = texture(Sampler_WaterRipples, fWaveTex1).xyz;
    vec3 rippleTex2 = texture(Sampler_WaterRipples, fWaveTex2).xyz;
    vec3 rippleTex3 = texture(Sampler_WaterRipples, fWaveTex3).xyz;
  
	// Average texture coordinates
	vec3 rippleTex = (rippleTex0 + rippleTex1 + rippleTex2 + rippleTex3) * 0.5;
	
	// Scale ripple texture coordinate
	vec3 refracTex = rippleTex * vec3(0.01, 0.01, 1.0);
	vec3 reflecTex = rippleTex * vec3(0.02, 0.02, 1.0);
	
	// Projected texture coordinate
	vec3 texCoord = fProjCoord.xyz / fProjCoord.w;
	texCoord = 0.5 + texCoord * 0.5;
	
	// Get output color
	vec4 colRefl = texture(Sampler_Reflection, texCoord.xy + reflecTex.xy);
	vec4 colRefr = texture(Sampler_Refraction, texCoord.xy + refracTex.xy);
	colRefr *= (1 - colRefr.a);
	outColor = colRefl * 0.4 + colRefr * 0.4;

}